@@ -1,3 +1,26 @@
+/*
+ *  charmap - GTK+ based simple character map
+ *
+ *  Copyright (C) 2014 Peter Pichler (this application)
+ *  Copyrught (C) 2010 Gabriel Schulhof (the author of scv-reader,
+ *                     a Maemo package this app was partially based on)
+ *  Copyright (C) 2010 The GNOME Charcter Map project (the icon)
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to Free Software Foundation Inc.,
+ *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include <hildon/hildon.h>
 #include <gucharmap/gucharmap.h>
 
@@ -117,15 +140,24 @@ static GtkButton *make_chapter_picker (GtkWidget *wnd)
 
 static void about_activated (GtkWidget * widget, GtkWindow * wnd)
 {
+  GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file(
+      "/usr/share/icons/hicolor/64x64/apps/charmap.png",
+      NULL);
+  GtkImage *img = g_object_new(GTK_TYPE_IMAGE, "visible", TRUE, NULL);
+  gtk_image_set_from_pixbuf(img, pixbuf);
+  g_object_unref(pixbuf);
+
   GtkLabel *lbl = make_label(-1);
-  gtk_label_set_text(lbl,
-      "A simple character map for Maemo. Version " APP_VERSION ".\n"
-      "Copyright © 2014 Peter Pichler (with special thanks "
-      "to Gabriel Schulhof, the author of scv-reader)\n"
-      "Released under GPL 3.");
+  gtk_label_set_justify(lbl, GTK_JUSTIFY_CENTER);
+  gtk_label_set_markup(lbl,
+      "<span size=\"xx-large\">" APP_NAME " " APP_VERSION "</span>\n"
+      "A simple character map for Maemo.\n\n"
+      "Copyright © 2014 Peter Pichler\n"
+      "(Using parts of code from the Maemo package scv-reader and the icon from the GNOME package gucharmap.)");
 
   GtkBox *vbox = g_object_new(GTK_TYPE_VBOX, "visible", TRUE, NULL);
-  gtk_box_pack_start(vbox, GTK_WIDGET(lbl), FALSE, FALSE, 5);
+  gtk_box_pack_start(vbox, GTK_WIDGET(img), FALSE, FALSE, 0);
+  gtk_box_pack_start(vbox, GTK_WIDGET(lbl), FALSE, FALSE, 0);
 
   GtkDialog *dlg = g_object_new(GTK_TYPE_DIALOG,
       "visible", TRUE,
