@@ -1,3 +1,26 @@
+/*
+ *  charmap - GTK+ based simple character map
+ *
+ *  Copyright (C) 2014 Peter Pichler (this application)
+ *  Copyrught (C) 2010 Gabriel Schulhof (the author of scv-reader,
+ *                     a Maemo package this app was partially based on)
+ *  Copyright (C) 2010 The GNOME Charcter Map project (the icon)
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to Free Software Foundation Inc.,
+ *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include <gucharmap/gucharmap.h>
 
 #include "maemo-gucharmap-chartable.h"
@@ -25,7 +48,7 @@ static double set_up_sync (const GtkAdjustment *p_src,
                            GtkAdjustment *my_adj,
                            GtkAdjustment *foreign_adj)
 {
-  static const double pixel_size = 100.0;
+  static const double pixel_size = 60.0;
   if (p_src == foreign_adj)
   {
     *p_dst = my_adj;
@@ -121,11 +144,9 @@ static void maemo_gucharmap_chartable_init (MaemoGucharmapChartable *chart)
   g_signal_connect(G_OBJECT(chart->my_vadj), "changed",       (GCallback)sync_adj,       chart);
   g_signal_connect(G_OBJECT(chart->my_vadj), "value-changed", (GCallback)sync_adj_value, chart);
 
-/*
-  PangoFontDescription *desc = pango_font_description_from_string("[][][40 px]");
+  PangoFontDescription *desc = pango_font_description_from_string("Nokia Sans 34px");
   gucharmap_chartable_set_font_desc(GUCHARMAP_CHARTABLE(chart), desc);
   pango_font_description_free(desc);
-*/
 }
 
 static void maemo_gucharmap_chartable_class_init (MaemoGucharmapChartableClass *chart_class)
